"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeUser = sanitizeUser;
exports.checkUser = checkUser;
exports.generateAnonymousId = generateAnonymousId;
const display_1 = require("../../tools/display");
const typeUtils_1 = require("../../tools/utils/typeUtils");
/**
 * Clone input data and ensure known user properties (id, name, email)
 * are strings, as defined here:
 * https://docs.datadoghq.com/logs/log_configuration/attributes_naming_convention/#user-related-attributes
 */
function sanitizeUser(newUser) {
    // We shallow clone only to prevent mutation of user data.
    const user = { ...newUser };
    const keys = ['id', 'name', 'email'];
    keys.forEach((key) => {
        if (key in user) {
            /* eslint-disable @typescript-eslint/no-base-to-string */
            user[key] = String(user[key]);
        }
    });
    return user;
}
/**
 * Simple check to ensure user is valid
 */
function checkUser(newUser) {
    const isValid = (0, typeUtils_1.getType)(newUser) === 'object';
    if (!isValid) {
        display_1.display.error('Unsupported user:', newUser);
    }
    return isValid;
}
function generateAnonymousId() {
    return Math.floor(Math.random() * Math.pow(36, 10))
        .toString(36)
        .padStart(10, '0');
}
//# sourceMappingURL=user.js.map